<?php

namespace Drupal\admin_notification\Form;

/**
 * @file
 * Contains Drupal\admin_notification\Form\AdminForm.
 */

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\State\StateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

class AdminForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function __construct(protected StateInterface $state) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('state'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'admin_notification_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['admin_notification_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Show admin notification'),
      '#default_value' => $this->state->get('admin_notification.enabled', FALSE),
    ];
    $form['admin_notification_message'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Admin notification message'),
      '#description' => $this->t('Message shown to logged-in users'),
      '#default_value' => $this->state->get('admin_notification.message', ''),
    ];
    $types = [
      'status' => $this->t('Status'),
      'warning' => $this->t('Warning'),
      'error' => $this->t('Error'),
    ];
    $form['admin_notification_type'] = [
      '#type' => 'select',
      '#options' => $types,
      '#title' => $this->t('Admin notification type'),
      '#description' => $this->t('Message type, defines how the message is formatted'),
      '#default_value' => $this->state->get('admin_notification.type', 'status'),
    ];
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = [
      'admin_notification.enabled' => $form_state->getValue('admin_notification_enabled'),
      'admin_notification.message' => $form_state->getValue('admin_notification_message'),
      'admin_notification.type' => $form_state->getValue('admin_notification_type'),
    ];
    $this->state->setMultiple($values);
  }

}
